Cheshire3 Object Model - PreParser
==================================

.. _objects-preParser-api:

API
---

.. autoclass:: cheshire3.baseObjects.PreParser
   :members:


.. _objects-preParser-implementations:

Implementations
---------------

The following implementations are included in the distribution by default:

.. autoclass:: cheshire3.preParser.NormalizerPreParser

.. autoclass:: cheshire3.preParser.UnicodeDecodePreParser

.. autoclass:: cheshire3.preParser.CmdLinePreParser

.. autoclass:: cheshire3.preParser.FileUtilPreParser

.. autoclass:: cheshire3.preParser.MagicRedirectPreParser

.. autoclass:: cheshire3.preParser.HtmlSmashPreParser

.. autoclass:: cheshire3.preParser.RegexpSmashPreParser

.. autoclass:: cheshire3.preParser.HtmlTidyPreParser

.. autoclass:: cheshire3.preParser.SgmlPreParser

.. autoclass:: cheshire3.preParser.AmpPreParser

.. autoclass:: cheshire3.preParser.MarcToXmlPreParser

.. autoclass:: cheshire3.preParser.MarcToSgmlPreParser

.. autoclass:: cheshire3.preParser.TxtToXmlPreParser

.. autoclass:: cheshire3.preParser.PicklePreParser

.. autoclass:: cheshire3.preParser.UnpicklePreParser

.. autoclass:: cheshire3.preParser.GzipPreParser

.. autoclass:: cheshire3.preParser.GunzipPreParser

.. autoclass:: cheshire3.preParser.B64EncodePreParser

.. autoclass:: cheshire3.preParser.B64DecodePreParser

.. autoclass:: cheshire3.preParser.PrintableOnlyPreParser

.. autoclass:: cheshire3.preParser.CharacterEntityPreParser
